@@ -12,7 +12,7 @@ function (qual = NULL)
             "2F1KVCNHMVHV8E9PBUB2A4J79LU20F"), c("Categorization Masters (Production)", 
             "2NDP2L92HECWY8NS8H3CK0CP5L9GHO"), c("Photo Moderation Masters (Sandbox)", 
             "2TGBB6BFMFFOM08IBMAFGGESC1UWJX"), c("Photo Moderation Masters (Production)", 
-            "21VZU98JHSTLZ5BPP4A9NOBJEK3DPG")))
+            "21VZU98JHSTLZ5BPP4A9NOBJEK3DPG")), stringsAsFactors = FALSE)
     names(quals) <- c("Qualification", "QualificationTypeId")
     if (!is.null(qual)) 
         return(as.character(quals[quals$Qualification == qual, 
