@@ -64,8 +64,9 @@ function (keyid, operation, signature, timestamp, GETparameters,
             }
             if (valid == FALSE) {
                 if (print.errors == TRUE) {
-                  cat("Request ", request.id, " Not Valid for URL:\n", 
-                    request.url, "\n", sep = "")
+                  cat("Request ", request.id, " not valid for API request:\n", 
+                    sep = "")
+                  cat(strsplit(request.url, "&")[[1]], sep = "\n                                     &")
                   errors <- ParseErrorCodes(xml = response)
                   for (i in 1:dim(errors)[1]) {
                     cat("Error (", errors[i, 1], "): ", errors[i, 
