@@ -49,16 +49,16 @@ function (hit = NULL, hit.type = NULL, revert = FALSE, keypair = credentials(),
             if (request$valid == TRUE) {
                 if (print == TRUE) {
                   if (revert == "false") 
-                    cat("HIT (", hitlist[i], ") set as Reviewing\n", 
+                    cat(i, ": HIT (", hitlist[i], ") set as Reviewing\n", 
                       sep = "")
                   if (revert == "true") 
-                    cat("HIT (", hitlist[i], ") set as Reviewable\n", 
+                    cat(i, ": HIT (", hitlist[i], ") set as Reviewable\n", 
                       sep = "")
                 }
             }
             else if (request$valid == FALSE) {
                 if (print == TRUE) 
-                  cat("Invalid Request for HIT ", hitlist[i], 
+                  cat(i, ": Invalid Request for HIT ", hitlist[i], 
                     "\n", sep = "")
             }
         }
