@@ -27,9 +27,9 @@ function (response.group = NULL, return.all = TRUE, pagenumber = "1",
     }
     GETparameters <- ""
     if (!is.null(response.group)) {
-        if (!response.group %in% c("Minimal", "HITQuestion", 
-            "HITDetail", "HITAssignmentSummary")) 
-            stop("ResponseGroup must be in c(Minimal,HITQuestion,HITDetail,HITAssignmentSummary)")
+        if (!response.group %in% c("Request", "Minimal", "HITDetail", 
+            "HITQuestion", "HITAssignmentSummary")) 
+            stop("ResponseGroup must be in c(Request,Minimal,HITDetail,HITQuestion,HITAssignmentSummary)")
         if (length(response.group) == 1) 
             GETparameters <- paste(GETparameters, "&ResponseGroup=", 
                 response.group, sep = "")
